package com.huimv.apiservice.controller;

import com.huimv.apiservice.entity.vo.*;
import com.huimv.apiservice.limit.annotation.Limit;
import com.huimv.apiservice.service.PigService;
import com.huimv.common.utils.PageUtils;
import com.huimv.common.utils.R;
import com.huimv.common.validate.ListValue;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.validation.constraints.Email;
import javax.validation.constraints.NotBlank;
import java.util.Map;
import java.util.Objects;

/**
 * @author yinhao
 * @date 2021/5/8 16:09
 */
@CrossOrigin
@RestController
@RequestMapping("/pig")
@Validated
public class PigController {

    @Autowired
    private PigService pigService;

    /**
     * 获取猪基本信息
     *
     * @param accessToken token
     * @param pigEarTagNo 耳标号
     * @return
     */
    //@Limit(key = "pig_getPigInfo",name = "pig/getPigInfo",prefix = "apiservice")
    @GetMapping("/getPigInfo")
    public R getPigInfo(@RequestParam(value = "accessToken") String accessToken,
                        @NotBlank(message = "耳标号不能为空!") @RequestParam("pigEarTagNo")  String pigEarTagNo) {
        Map<String, Object> map = pigService.getPigInfoByEarTagNo(pigEarTagNo);
        return Objects.requireNonNull(R.ok().put("code", 1000)).put("data", map);
    }


    /**
     * 获取多媒体接口(照片/视频)
     *
     * @param accessToken token
     * @param pigEarTagNo 耳标号
     * @return
     */
    @GetMapping("/getImage")
    public R getImage(@RequestParam(value = "accessToken") String accessToken,
                      @NotBlank(message = "耳标号111不能为空!") @RequestParam("pigEarTagNo")  String pigEarTagNo) {
        PigImageVo pigImageVo = pigService.getImageByEarTagNo(pigEarTagNo);
        return Objects.requireNonNull(R.ok().put("code", 1000)).put("data", pigImageVo);
    }

    /**
     * 根据品种名称获取猪的数量和基本信息
     *
     * @param accessToken token
     * @param breedName   品种名称
     * @return
     */
    @GetMapping("/getListByBreed")
    public R getListByBreed(@RequestParam(value = "accessToken") String accessToken,
                            @RequestParam("breedName") @NotBlank(message = "品种名称不能为空!") String breedName) {
        PageUtils page = pigService.getListByBreed(breedName);
        return Objects.requireNonNull(R.ok().put("code", 1000)).put("page", page);
    }

    /**
     * 获取环境数据
     *
     * @param accessToken token
     * @param pigEarTagNo 耳标号
     * @return
     */
    @GetMapping("/getIndoorEnv")
    public R getIndoorEnv(@RequestParam(value = "accessToken") String accessToken,
                          @NotBlank(message = "耳标号不能为空!") @RequestParam("pigEarTagNo") String pigEarTagNo) {
        EnvVo envVo = pigService.getIndoorEnv(pigEarTagNo);
        return Objects.requireNonNull(R.ok().put("code", 1000)).put("data", envVo);
    }

    /**
     * 修改认养状态
     *
     * @param accessToken token
     * @param pigEarTagNo 耳标号
     * @return
     */
    @GetMapping("/adopt")
    public R adopt(@RequestParam(value = "accessToken") String accessToken,
                   @RequestParam("pigEarTagNo") @NotBlank(message = "耳标号不能为空!") String pigEarTagNo) {
        pigService.adopt(pigEarTagNo);
        return Objects.requireNonNull(R.ok().put("code", 1000)).put("msg", "认养成功!");
    }

    /**
     * 出栏
     *
     * @param accessToken token
     * @param pigEarTagNo 耳标号
     * @return
     */
    @GetMapping("/outFence")
    public R outFence(@RequestParam(value = "accessToken", required = false) String accessToken,
                      @RequestParam("pigEarTagNo") @NotBlank(message = "耳标号不能为空!") String pigEarTagNo,
                      @ListValue(vals = {1,2,3}) @RequestParam("status") Integer status) {
        pigService.outFence(pigEarTagNo,status);
        return Objects.requireNonNull(R.ok().put("code", 1000)).put("msg", "更新出栏状态成功!");
    }
}
